| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenSSL.X509.SystemStore
- contextLoadSystemCerts :: SSLContext -> IO ()
Documentation
contextLoadSystemCerts :: SSLContext -> IO () Source #
Add the certificates from the system-wide certificate store to the
given openssl context. Note that
this does not automatically enable peer certificate verification.
You also need to call contextSetVerificationMode and
check manually if the hostname matches the one specified in the
certificate. You can find information about how to do the latter
here.